@@ -1,6 +1,6 @@
 ;;; helm-font --- Font and ucs selection for Helm -*- lexical-binding: t -*-
 
-;; Copyright (C) 2012 ~ 2015 Thierry Volpiatto <thierry.volpiatto@gmail.com>
+;; Copyright (C) 2012 ~ 2016 Thierry Volpiatto <thierry.volpiatto@gmail.com>
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -21,6 +21,10 @@
 (require 'helm)
 (require 'helm-help)
 
+(defgroup helm-font nil
+  "Related applications to display fonts in helm."
+  :group 'helm)
+
 (defvar helm-ucs-map
   (let ((map (make-sparse-keymap)))
     (set-keymap-parent map helm-map)
@@ -31,6 +35,10 @@
     map)
   "Keymap for `helm-ucs'.")
 
+(defface helm-ucs-char
+  '((((class color) (background dark))  (:foreground "Gold")))
+  "Face used to display ucs characters."
+  :group 'helm-font)
 
 ;;; Xfont selection
 ;;
@@ -63,31 +71,34 @@
 ;;; 𝕌𝕔𝕤 𝕊𝕪𝕞𝕓𝕠𝕝 𝕔𝕠𝕞𝕡𝕝𝕖𝕥𝕚𝕠𝕟
 ;;
 ;;
-(defvar helm-ucs--max-len 0)
+(defvar helm-ucs--max-len nil)
 (defvar helm-ucs--names nil)
+(defvar helm-ucs-history nil)
+
 (defun helm-calculate-ucs-max-len ()
   "Calculate the length of longest `ucs-names' candidate."
-  (cl-loop with count = 0
-        for (n . v) in (ucs-names)
-        for len = (length n)
-        if (> len count)
-        do (setq count len)
-        finally return count))
+  (cl-loop for (_n . v) in (ucs-names)
+           maximize (length (format "#x%x:" v)) into code
+           maximize (max 1 (string-width (format "%c" v))) into char
+           finally return (cons code char)))
 
 (defun helm-ucs-init ()
   "Initialize an helm buffer with ucs symbols.
 Only math* symbols are collected."
-  (unless (> helm-ucs--max-len 0)
+  (unless helm-ucs--max-len
     (setq helm-ucs--max-len
           (helm-calculate-ucs-max-len)))
   (or helm-ucs--names
       (setq helm-ucs--names
             (cl-loop for (n . v) in (ucs-names)
-                     for len = (length n)
-                     for diff = (+ (- helm-ucs--max-len len) 2)
-                     unless (string= "" n)
-                     collect (format "%s:%s%c #x%x"
-                                     n (make-string diff ? ) v v)))))
+                     for len = (length (format "#x%x:" v))
+                     for diff = (- (car helm-ucs--max-len) len)
+                     for code = (format "(#x%x): " v)
+                     for char = (propertize (format "%c" v)
+                                            'face 'helm-ucs-char)
+                     unless (string= "" n) collect
+                     (concat code (make-string diff ? )
+                             char "  " n)))))
 
 (defun helm-ucs-forward-char (_candidate)
   (with-helm-current-buffer
@@ -102,17 +113,19 @@ Only math* symbols are collected."
     (delete-char -1)))
 
 (defun helm-ucs-insert (candidate n)
-  (with-helm-current-buffer
-    (string-match "^\\([^:]+\\): +\\(.\\) \\(#x[a-f0-9]+\\)$" candidate)
-    (insert (match-string n candidate))))
-
-(defun helm-ucs-insert-name (candidate)
-  (helm-ucs-insert candidate 1))
+  (when (string-match
+         "^(\\(#x[a-f0-9]+\\)): *\\(.\\) *\\([^:]+\\)+"
+         candidate)
+    (with-helm-current-buffer
+      (insert (match-string n candidate)))))
 
 (defun helm-ucs-insert-char (candidate)
   (helm-ucs-insert candidate 2))
 
 (defun helm-ucs-insert-code (candidate)
+  (helm-ucs-insert candidate 1))
+
+(defun helm-ucs-insert-name (candidate)
   (helm-ucs-insert candidate 3))
 
 (defun helm-ucs-persistent-insert ()
@@ -146,8 +159,9 @@ Only math* symbols are collected."
 (defvar helm-source-ucs
   (helm-build-in-buffer-source "Ucs names"
     :data #'helm-ucs-init
+    :get-line #'buffer-substring
     :help-message 'helm-ucs-help-message
-    :match-part (lambda (candidate) (car (split-string candidate ":")))
+    :match-part (lambda (candidate) (cadr (split-string candidate ":")))
     :filtered-candidate-transformer
     (lambda (candidates _source) (sort candidates #'helm-generic-sort-fn))
     :action '(("Insert character" . helm-ucs-insert-char)
@@ -169,8 +183,12 @@ Only math* symbols are collected."
 (defun helm-ucs ()
   "Preconfigured helm for `ucs-names' math symbols."
   (interactive)
-  (helm :sources 'helm-source-ucs
-        :keymap  helm-ucs-map))
+  (let ((char (helm-aif (char-after) (string it))))
+    (helm :sources 'helm-source-ucs
+          :keymap  helm-ucs-map
+          :history 'helm-ucs-history
+          :input (and char (multibyte-string-p char) char)
+          :buffer "*helm ucs*")))
 
 (provide 'helm-font)
 
