@@ -198,6 +198,7 @@ Fill in the symbol at point by default."
                      'helm-source-imenu))
          (imenu-p (eq source 'helm-source-imenu))
          (imenu-auto-rescan imenu-p)
+         (str (thing-at-point 'symbol))
          (helm-execute-action-at-once-if-one
           (and imenu-p
                helm-imenu-execute-action-at-once-if-one))
@@ -207,9 +208,8 @@ Fill in the symbol at point by default."
                 (format "\\_<%s\\_>" (car (semantic-current-tag))))))
     (helm :sources source
           :candidate-number-limit 9999
-          :preselect (if (or arg imenu-p)
-                         (thing-at-point 'symbol)
-                         tag)
+          :default (and imenu-p (list (concat "\\_<" str "\\_>") str))
+          :preselect (if (or arg imenu-p) str tag)
           :buffer "*helm semantic/imenu*")))
 
 (provide 'helm-semantic)
