@@ -211,16 +211,6 @@ In this case last position is added to the register
   "Face used to highlight item matched in a selected line."
   :group 'helm-faces)
 
-
-;; CUA workaround
-(defadvice cua-delete-region (around helm-avoid-cua activate)
-  (ignore-errors ad-do-it))
-
-(defadvice copy-region-as-kill (around helm-avoid-cua activate)
-  (if cua-mode
-      (ignore-errors ad-do-it)
-    ad-do-it))
-
 
 ;;; Utils functions
 ;;
@@ -276,10 +266,11 @@ Default is `helm-current-buffer'."
   "Goto LINENO opening only outline headline if needed.
 Animation is used unless NOANIM is non--nil."
   (helm-log-run-hook 'helm-goto-line-before-hook)
+  (helm-match-line-cleanup)
   (goto-char (point-min))
   (helm-goto-char (point-at-bol lineno))
   (unless noanim
-    (helm-highlight-current-line nil nil nil nil 'pulse)))
+    (helm-highlight-current-line)))
 
 (defun helm-save-pos-to-register-before-jump ()
   "Save current buffer position to `helm-save-pos-before-jump-register'.
@@ -438,10 +429,10 @@ that is sorting is done against real value of candidate."
   "Extract hostname from an incomplete tramp file name.
 Return nil on valid file name remote or not."
   (let* ((str (helm-basename fname))
-         (split (split-string str ":"))
-         (meth (car (member (car split) (mapcar 'car tramp-methods))))) 
-    (when (and meth (<= (length split) 2))
-      (cadr split))))
+         (split (split-string str ":" t))
+         (meth (car (member (car split)
+                            (helm-ff-get-tramp-methods))))) 
+    (when meth (car (last split)))))
 
 (cl-defun helm-file-human-size (size &optional (kbsize helm-default-kbsize))
   "Return a string showing SIZE of a file in human readable form.
@@ -593,7 +584,7 @@ If STRING is non--nil return instead a space separated string."
 (defvar helm-match-line-overlay nil)
 (defvar helm--match-item-overlays nil)
 
-(defun helm-highlight-current-line (&optional start end buf face pulse)
+(defun helm-highlight-current-line (&optional start end buf face)
   "Highlight and underline current position"
   (let* ((start (or start (line-beginning-position)))
          (end (or end (1+ (line-end-position))))
@@ -636,10 +627,7 @@ If STRING is non--nil return instead a space separated string."
                                 helm--match-item-overlays)
                           (overlay-put ov 'face 'helm-match-item)
                           (overlay-put ov 'priority 1)))))))
-    (recenter)
-    (when pulse
-      (sit-for 0.3)
-      (helm-match-line-cleanup))))
+    (recenter)))
 
 (defun helm-match-line-cleanup ()
   (when helm-match-line-overlay
@@ -659,8 +647,12 @@ If STRING is non--nil return instead a space separated string."
              (eq helm-split-window-state 'vertical))
     (set-window-text-height (helm-window) helm-resize-on-pa-text-height)))
 
+(defun helm-match-line-cleanup-pulse ()
+  (run-with-idle-timer 0.3 nil #'helm-match-line-cleanup))
+
 (add-hook 'helm-after-persistent-action-hook 'helm-persistent-autoresize-hook)
 (add-hook 'helm-cleanup-hook 'helm-match-line-cleanup)
+(add-hook 'helm-after-action-hook 'helm-match-line-cleanup-pulse)
 (add-hook 'helm-after-persistent-action-hook 'helm-match-line-update)
 
 ;;; Popup buffer-name or filename in grep/moccur/imenu-all.
